@@ -14,7 +14,6 @@ from .domain.protocol.client_protocol import ClientProtocol
 from .domain.exceptions.could_not_connect_to_server import CouldNotConnectToServerException
 from .logging import log
 
-
 DEFAULT_RS232_BAUDRATE = 921600
 
 SDK_RESPONSE_FORMAT_JSON = "JSON"
@@ -110,6 +109,24 @@ class SDK:
     def disconnect(self):
         self._client_protocol.disconnect()
 
+    def __reset_databases(self):
+        return self._client_protocol.reset_databases()
+
+    def create_instrument(self, new_instrument, response_format=None):
+        created_instrument_as_json_string = self._client_protocol.create_instrument_as_json_string(
+            new_instrument)
+        return self.__format_response(created_instrument_as_json_string, response_format)
+
+    def update_instrument(self, instrument_id, updated_instrument, response_format=None):
+        updated_instrument_as_json_string = self._client_protocol.update_instrument_as_json_string(
+            instrument_id, updated_instrument)
+        return self.__format_response(updated_instrument_as_json_string, response_format)
+
+    def delete_instrument(self, instrument_id, response_format=None):
+        deleted_instrument = self._client_protocol.delete_instrument_as_json_string(
+            instrument_id)
+        return self.__format_response(deleted_instrument, response_format)
+
     def get_instruments(self, response_format=None):
         """
         Returns the list of instruments dictionaries
@@ -141,7 +158,8 @@ class SDK:
             return False
 
     def send_command(self, instrument_id, command_invocation, response_format=None, convert_result_to=None):
-        if response_format == SDK_RESPONSE_FORMAT_JSON or (response_format == None and self._default_response_format == SDK_RESPONSE_FORMAT_JSON):
+        if response_format == SDK_RESPONSE_FORMAT_JSON or (
+                response_format == None and self._default_response_format == SDK_RESPONSE_FORMAT_JSON):
             # If response format is json convert_result_to is ignored
             return self._client_protocol.send_command_and_result_as_json_string(instrument_id, command_invocation)
 
@@ -173,6 +191,19 @@ class SDK:
 
         return command_execution_result
 
+    def send_file(self, file_path, file_target_name):
+        with open(file_path, "rb") as file:
+            data = file.read()
+            return self._client_protocol.send_file(data, file_target_name)
+
+    def get_file(self, remote_file_name, file_target_name):
+        file_bytes = self._client_protocol.get_file(remote_file_name, file_target_name)
+        with open(file_target_name, "wb") as file:
+            file.write(file_bytes)
+
+    def execute_bash_command(self, command, capture_stdout=False, capture_stderr=False):
+        return self._client_protocol.execute_bash_command(command, capture_stdout, capture_stderr)
+
     def __format_response(self, json_string, response_format):
         response_format = response_format if response_format else self._default_response_format
         assert response_format in SDK_VALID_RESPONSE_FORMATS
